@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import shutil
 import sys
-
 from pathlib import Path
 from typing import Any, Generic, Iterator, List, Mapping, Optional, Type, TypeVar, Union
 
@@ -33,7 +32,7 @@ class BaseProject(Generic[SpecT]):
         if spec:
             # Store spec parameter into __SPEC__ attribute of child class
             # This attribute will be available to all instances of child classes
-            cls.__SPEC__ = spec
+            cls.__SPEC__ = spec  # pyright: ignore
 
     def __init__(self, filepath: Union[str, Path]):
         """Create a new instance of BaseProject.
@@ -138,10 +137,11 @@ class BaseProject(Generic[SpecT]):
 
 
 class BasePythonProject(BaseProject[SpecT]):
-
     _python_executable: Path
 
-    def __init__(self, filepath: Union[str, Path], venv_path: Union[str, Path, None] = None):
+    def __init__(
+        self, filepath: Union[str, Path], venv_path: Union[str, Path, None] = None
+    ):
         super().__init__(filepath)
         self.venv_path = Path(venv_path) if venv_path else self.root / ".venv"
 
