@@ -66,7 +66,7 @@ class KProject(ReadWriteYAMLMixin, BasePythonProject[KProjectSpec], spec=KProjec
         filepath: Union[str, Path],
         repo: Optional[KRepo] = None,
         workspace: Optional[str] = None,
-        venv_path: Union[str, Path, None] = None
+        venv_path: Union[str, Path, None] = None,
     ) -> None:
         super().__init__(filepath, venv_path=repo.venv_path if repo else venv_path)
         self.repo = repo
@@ -306,12 +306,14 @@ class KProject(ReadWriteYAMLMixin, BasePythonProject[KProjectSpec], spec=KProjec
         # Generate poetry config by merging raw config and gather dependencies, extras and group
         poetry_config = PoetryConfig(
             **raw_poetry_config,
-            dependencies=dependencies,
+            dependencies=dependencies,  # pyright: ignore
             extras=extras,
             group=groups,
         )
         # Generate pyproject file
-        return PyProjectSpec(tool={"poetry": poetry_config}, build_system=build_system)
+        return PyProjectSpec(
+            tool={"poetry": poetry_config}, build_system=build_system  # pyright: ignore
+        )
 
     def write_pyproject(
         self,
@@ -641,6 +643,7 @@ class KProject(ReadWriteYAMLMixin, BasePythonProject[KProjectSpec], spec=KProjec
         push: bool = False,
         build_args: Optional[Dict[str, str]] = None,
         platforms: Optional[List[str]] = None,
+        provenance: bool = False,
         suffix: Optional[str] = None,
         output_dir: Union[str, Path, None] = None,
         build_dist: bool = True,
@@ -739,6 +742,9 @@ class KProject(ReadWriteYAMLMixin, BasePythonProject[KProjectSpec], spec=KProjec
                 platform = spec.platforms
             if platform:
                 cmd.add_repeat_option("--platform", platform)
+            # Only add option when set to False, because defaut behaviour is to add provenance on latest buildx versions
+            if provenance is False:
+                cmd.add_option("--provenance", "false")
             cmd.add_argument(
                 Path(self.root, spec.context).resolve(True).as_posix()
                 if spec.context
