@@ -7,6 +7,11 @@ from pydantic import Field
 from .base import AliasedModel
 
 
+class LockedFile(AliasedModel):
+    file: str
+    file_hash: str = Field(alias="hash")
+
+
 class LockedPackage(AliasedModel):
     name: str
     version: str
@@ -16,6 +21,10 @@ class LockedPackage(AliasedModel):
     python_versions: Optional[str] = Field(alias="python-versions")
     extras: Optional[Dict[str, List[str]]] = {}
     dependencies: Optional[Dict[str, Union[str, Dict[str, Any]]]] = {}
+    files: Optional[List[LockedFile]]
+
+    class Config(AliasedModel.Config):
+        extra = "allow"
 
 
 class LockedMetadata(AliasedModel):
